@@ -3,7 +3,7 @@ import sys
 
 
 def delegate(
-    delegatee: callable, kwonly: bool = False, delegate_docstring: bool = True
+    delegatee: callable, *, kwonly: bool = False, delegate_docstring: bool = True, ignore: set[str] = set()
 ):
     """
     Delegate kwargs to another function.
@@ -32,34 +32,36 @@ def delegate(
     """
 
     def decorator(
-        delegator: callable, ):
+        delegator: callable
+    ):
         "Transfer keyword arguments, including annotations and docstrings, from delegatee to delegator"
         delegatee_sig = inspect.signature(delegatee)
         delegator_sig = inspect.signature(delegator)
         # The last parameter of the delegator must be **kwargs.
         assert delegator_sig.parameters[list(delegator_sig.parameters.keys())[-1]].kind == inspect.Parameter.VAR_KEYWORD
-        # Transfer annotations from delegatee to delegator for keyword arguments without annotations in delegator
-        for name, param in delegatee_sig.parameters.items():
-            if param.kind == param.KEYWORD_ONLY or param.kind == param.POSITIONAL_OR_KEYWORD:
-                if name in delegator_sig.parameters and delegator_sig.parameters[name].annotation is inspect._empty:
-                    delegator.__annotations__[name] = param.annotation
         # Gather parameters from delegatee
         # Exclude:
         # - arguments that are already defined in delegator
         # - positional-only arguments
         # - if kwonly, positional-or-keyword arguments
         delegatee_kwargs = {}
-        for k, v in delegatee_sig.parameters.items():
-            if v.kind == v.VAR_KEYWORD:
-                delegatee_kwargs[k] = v
-            elif k in delegator_sig.parameters:
+        for name, param in delegatee_sig.parameters.items():
+            if name in ignore:
                 continue
-            elif v.kind == v.POSITIONAL_OR_KEYWORD:
+            # Transfer annotations from delegatee to delegator for keyword arguments without annotations in delegator
+            if param.kind == param.KEYWORD_ONLY or param.kind == param.POSITIONAL_OR_KEYWORD and name not in ignore:
+                if name in delegator_sig.parameters and delegator_sig.parameters[name].annotation is inspect._empty:
+                    delegator.__annotations__[name] = param.annotation
+            if param.kind == param.VAR_KEYWORD:
+                delegatee_kwargs[name] = param
+            elif name in delegator_sig.parameters:
+                continue
+            elif param.kind == param.POSITIONAL_OR_KEYWORD:
                 if not kwonly:
                     # Make the argument keyword-only
-                    delegatee_kwargs[k] = v.replace(kind=v.KEYWORD_ONLY)
-            elif v.kind == v.KEYWORD_ONLY:
-                delegatee_kwargs[k] = v
+                    delegatee_kwargs[name] = param.replace(kind=param.KEYWORD_ONLY)
+            elif param.kind == param.KEYWORD_ONLY:
+                delegatee_kwargs[name] = param
         assert all([param.kind != param.VAR_KEYWORD for param in delegatee_sig.parameters.values()]) or any(
             [param.kind == param.VAR_KEYWORD for param in delegatee_kwargs.values()]
         ), f"If the delegatee has a **kwargs parameter, the delegator must have a **kwargs parameter. Got signatures {delegatee_sig} and {delegator_sig} for delegatee and delegator, respectively, but computed signature {inspect.Signature(delegatee_kwargs.values())} for the combined parameters."
@@ -138,9 +140,23 @@ if "pytest" in sys.modules:
         return func, func2, func2_expected
 
 
+    def make_ignore_fns():
+        def func(a, b, c):
+            "A docstring"
+
+        @delegate(func, ignore={"a"})
+        def func2(**kwargs):
+            return func(**kwargs)
+
+        def func2_expected(*, b, c):
+            "A docstring"
+
+        return func, func2, func2_expected
+
+
     @pytest.mark.parametrize(
         "delegatee, delegator, expected",
-        [make_readme_example_1_fns(), make_readme_example_2_fns(), make_other_1_fns(), make_other_2_fns(), ]
-    )
+        [make_readme_example_1_fns(), make_readme_example_2_fns(), make_other_1_fns(), make_other_2_fns(),
+            make_ignore_fns()], )
     def test_delegate(delegatee, delegator, expected):
         assert inspect.signature(delegator) == inspect.signature(expected)
